ExactRetrievalError

Enum ExactRetrievalError 

pub enum ExactRetrievalError {
    EmptyCandidateKey,
    DuplicateCandidateKey,
    DimensionMismatch {
        expected: u16,
        found: u16,
    },
    ZeroLimit,
    ResultLimitExceeded {
        requested: usize,
        maximum: usize,
    },
    InvalidMinimumScore,
    InvalidMinimumMargin,
    CandidateBudgetExceeded {
        maximum: u64,
    },
    CandidateByteBudgetExceeded {
        maximum: u64,
    },
    TimedOut,
    ArithmeticOverflow,
}
Failure to execute durable exact retrieval completely.

Variants



EmptyCandidateKey

Candidate keys must be nonempty.



DuplicateCandidateKey

Candidate keys must be unique in one space.



DimensionMismatch

Candidate and query dimensions must match.

Fields

expected: u16

Query dimension.

found: u16

Candidate dimension.



ZeroLimit

At least one match must be requested.



ResultLimitExceeded

The requested result count exceeds policy.

Fields

requested: usize

Requested result count.

maximum: usize

Maximum result count.



InvalidMinimumScore

The score threshold is outside the canonical cosine range.



InvalidMinimumMargin

The margin is outside the canonical cosine range width.



CandidateBudgetExceeded

The global candidate budget was exhausted.

Fields

maximum: u64

Maximum candidates.



CandidateByteBudgetExceeded

The aggregate candidate key/vector byte budget was exhausted.

Fields

maximum: u64

Maximum aggregate candidate bytes.



TimedOut

The cooperative timeout elapsed.



ArithmeticOverflow

Checked integer arithmetic failed.