pub enum ExactRetrievalError {
EmptyCandidateKey,
DuplicateCandidateKey,
DimensionMismatch {
expected: u16,
found: u16,
},
ZeroLimit,
ResultLimitExceeded {
requested: usize,
maximum: usize,
},
InvalidMinimumScore,
InvalidMinimumMargin,
CandidateBudgetExceeded {
maximum: u64,
},
CandidateByteBudgetExceeded {
maximum: u64,
},
TimedOut,
ArithmeticOverflow,
}Expand description
Failure to execute durable exact retrieval completely.
Variants
EmptyCandidateKey
Candidate keys must be nonempty.
DuplicateCandidateKey
Candidate keys must be unique in one space.
DimensionMismatch
Candidate and query dimensions must match.
ZeroLimit
At least one match must be requested.
ResultLimitExceeded
The requested result count exceeds policy.
InvalidMinimumScore
The score threshold is outside the canonical cosine range.
InvalidMinimumMargin
The margin is outside the canonical cosine range width.
CandidateBudgetExceeded
The global candidate budget was exhausted.
CandidateByteBudgetExceeded
The aggregate candidate key/vector byte budget was exhausted.
TimedOut
The cooperative timeout elapsed.
ArithmeticOverflow
Checked integer arithmetic failed.